package javax.swing;

import java.util.ListIterator;
import java.awt.Window;
import java.util.LinkedList;
import java.awt.ComponentOrientation;
import java.io.Serializable;
import java.awt.Component;
import java.util.Comparator;

final class LayoutComparator implements Comparator<Component>, Serializable
{
    private static final int ROW_TOLERANCE = 10;
    private boolean horizontal;
    private boolean leftToRight;
    
    LayoutComparator() {
        this.horizontal = true;
        this.leftToRight = true;
    }
    
    void setComponentOrientation(ComponentOrientation componentOrientation) {
        this.horizontal = componentOrientation.isHorizontal();
        this.leftToRight = componentOrientation.isLeftToRight();
    }
    
    @Override
    public int compare(Component parent, Component parent2) {
        if (parent == parent2) {
            return 0;
        }
        Label_0198: {
            if (parent.getParent() != parent2.getParent()) {
                LinkedList<Component> list = new LinkedList();
                while (parent != null) {
                    list.add(parent);
                    if ((parent instanceof Window)) {
                        break;
                    }
                    parent = parent.getParent();
                }
                if (parent == null) {
                    throw new ClassCastException();
                }
                LinkedList o = new LinkedList();
                while (parent2 != null) {
                    o.add(parent2);
                    if ((parent2 instanceof Window)) {
                        break;
                    }
                    parent2 = parent2.getParent();
                }
                if (parent2 == null) {
                    throw new ClassCastException();
                }
                ListIterator<Object> listIterator = list.listIterator(list.size());
                ListIterator<Object> listIterator2 = o.listIterator(o.size());
                while (listIterator.hasPrevious()) {
                    parent = (Component)listIterator.previous();
                    if (listIterator2.hasPrevious()) {
                        parent2 = (Component)listIterator2.previous();
                        if (parent != parent2) {
                            break Label_0198;
                        }
                        continue;
                    }
                    else {
                        return 1;
                    }
                }
                return -1;
            }
        }
        int x = parent.getX();
        int y = parent.getY();
        int x2 = parent2.getX();
        int y2 = parent2.getY();
        int n = parent.getParent().getComponentZOrder(parent) - parent2.getParent().getComponentZOrder(parent2);
        if (this.horizontal) {
            if (this.leftToRight) {
                if (Math.abs(y - y2) < 10) {
                    return (x < x2) ? -1 : ((x > x2) ? 1 : n);
                }
                return (y < y2) ? -1 : 1;
            }
            else {
                if (Math.abs(y - y2) < 10) {
                    return (x > x2) ? -1 : ((x < x2) ? 1 : n);
                }
                return (y < y2) ? -1 : 1;
            }
        }
        else if (this.leftToRight) {
            if (Math.abs(x - x2) < 10) {
                return (y < y2) ? -1 : ((y > y2) ? 1 : n);
            }
            return (x < x2) ? -1 : 1;
        }
        else {
            if (Math.abs(x - x2) < 10) {
                return (y < y2) ? -1 : ((y > y2) ? 1 : n);
            }
            return (x > x2) ? -1 : 1;
        }
    }
}
